import 'package:json_annotation/json_annotation.dart';

part 'ocr_data.g.dart';

///OCR action result
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class OcrResult {
  ///Recognized plain text
  String plainText;

  ///Optional file URI of generated PDF file (if requested via options).
  String pdfFileUri;

  OcrResult(this.plainText, this.pdfFileUri);

  factory OcrResult.fromJson(Map<String, dynamic> json) =>
      _$OcrResultFromJson(json);

  Map<String, dynamic> toJson() => _$OcrResultToJson(this);
}

///OCR options
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class OcrOptions {
  ///A list with OCR languages of the text to be recognized (e.g. ["en", "de"]).
  List<String> languages;

  ///Flag to generate a PDF with OCR layer text (sandwiched PDF).
  bool shouldGeneratePdf;

  OcrOptions({this.languages, this.shouldGeneratePdf});

  factory OcrOptions.fromJson(Map<String, dynamic> json) =>
      _$OcrOptionsFromJson(json);

  Map<String, dynamic> toJson() => _$OcrOptionsToJson(this);
}

///Sdk OCR configs
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class SdkOcrConfig {
  ///List of languages that installed into sdk (downloaded to languageDataPath, or attached from assets)
  List<String> installedLanguages;

  ///Folder where tesseract ocr blobs stores
  @JsonKey(nullable: true)
  String languageDataPath;

  SdkOcrConfig(this.installedLanguages, this.languageDataPath);

  factory SdkOcrConfig.fromJson(Map<String, dynamic> json) =>
      _$SdkOcrConfigFromJson(json);

  Map<String, dynamic> toJson() => _$SdkOcrConfigToJson(this);
}
